IEventHandler<TEvent extends IEvent> class abstract interface

A handler for events that implements the IActionHandler interface.

Event handlers process events but don't return any value (void).

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(TEvent action) → Future<void>
Handles the given action and returns a result.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited