IQuery<TResult> class abstract interface

A query is a type that represents a IQuery.

Queries are used to retrieve data from the state of the application without mutating the state.

This class MUST use the @MappableClass annotation and implement the dart_mappable functionality. To ensure this behavior, this interface will ask for toJson and toMap implementations (which should be provided by the dart_mappable package, and not created manually). This ensures this class is safe to compare by value.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited